@@ -35,14 +35,14 @@ _pkg_config = {
     'py_conf_inc_dir':    '/usr/local/include/python3.6m',
     'py_inc_dir':         '/usr/local/include/python3.6m',
     'py_lib_dir':         '/usr/local/lib/python3.6/config',
-    'py_version':         0x030600,
+    'py_version':         0x030604,
     'qt_framework':       0,
-    'sip_bin':            '/usr/local/bin/sip',
+    'sip_bin':            '/usr/local/bin/sip-3',
     'sip_config_args':    '-b /usr/local/bin -d /usr/local/lib/python3.6/site-packages -e /usr/local/include/python3.6m -v /usr/local/share/sip INCDIR=/usr/local/include LIBDIR=/usr/local/lib CC=cc CXX=c++ CFLAGS=-O2 -pipe   CXXFLAGS=-O2 -pipe  ',
     'sip_inc_dir':        '/usr/local/include/python3.6m',
     'sip_mod_dir':        '/usr/local/lib/python3.6/site-packages',
-    'sip_version':        0x041201,
-    'sip_version_str':    '4.18.1',
+    'sip_version':        0x041303,
+    'sip_version_str':    '4.19.3',
     'universal':          ''
 }
 
